package com.me.brickbuster.entity;

import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.math.MathUtils;
import com.badlogic.gdx.math.Vector2;
import com.me.brickbuster.BrickBuster;
import com.me.brickbuster.Utils;

public class Ball extends Entity {

	public static final int RADIUS = 18;
	public static final Color BALL_COLOR = Color.CHARTREUSE;

	public Vector2 direction;
	public float speed;

	public Ball(BrickBuster brickBuster) {
		super(brickBuster, BrickBuster.WIDTH/2, Paddle.PADDLE_Y + RADIUS + Paddle.PADDLE_HEIGHT/2);
	}

	@Override
	public void render() {
		getShapeRenderer().begin(ShapeRenderer.ShapeType.Filled);
		getShapeRenderer().setColor(BALL_COLOR);
		getShapeRenderer().circle(this.getX(), this.getY(), RADIUS);
		getShapeRenderer().end();
	}

	@Override
	public void update(float dt) {
		if (!getBrickBuster().isPlaying()) {
			return;
		}

		int newX = getX() + (int) (direction.x * speed);
		int newY = getY() + (int) (direction.y * speed);

		if (newX + RADIUS > BrickBuster.WIDTH) {
			Utils.reflect(direction, BrickBuster.RIGHT_EDGE);
		} else if (newY + RADIUS > BrickBuster.HEIGHT) {
			Utils.reflect(direction, BrickBuster.TOP_EDGE);
		} else if (newX - RADIUS < 0) {
			Utils.reflect(direction, BrickBuster.LEFT_EDGE);
		} else if (newY - RADIUS < 0) {
			Utils.reflect(direction, BrickBuster.BOTTOM_EDGE);
		}

		setX(getX() + (int) (direction.x * speed));
		setY(getY() + (int) (direction.y * speed));
	}

	public void launch() {
		float angle = MathUtils.random(MathUtils.PI/2) + MathUtils.PI/4;
		direction = new Vector2(MathUtils.cos(angle), MathUtils.sin(angle));
		speed = 5;
	}
}
